#ifndef AVSCANOP_H
#define AVSCANOP_H

#include <glib.h>
#include "scanner_opts.h"


extern gchar *AVScanGetAVEngineNameVersionString(void);

extern gint AVScanOP(
	const gchar *db_path,
	GList *path_list,
	const gboolean recursive,
	const gboolean executables_only,
	const gboolean ignore_links,
	gboolean *reload, gint *stop_count,
	scanner_opts_struct *scanner_opts
);


#endif	/* AVSCANOP_H */
